Index: wp-includes/cache.php
===================================================================
--- wp-includes/cache.php	(revision 3443)
+++ wp-includes/cache.php	(working copy)
@@ -396,8 +396,8 @@
 		if (defined('DISABLE_CACHE'))
 			return;
 
-		// Disable the persistent cache if safe_mode is on.
-		if ( ini_get('safe_mode') )
+		// Disable the persistent cache if safe_mode is on, unless CACHE_ENABLED is set to true
+		if ( ini_get('safe_mode') && !(defined('CACHE_ENABLED') && CACHE_ENABLED))
 			return;
 
 		if (defined('CACHE_PATH'))

